# Oriole-Service

**Rapidly create services.**

[![build](https://travis-ci.org/zhouxiaoxiang/oriole-service.png?branch=master)](https://travis-ci.org/zhouxiaoxiang/oriole-service)

**[Framework]**

[Orile-Service](https://github.com/zhouxiaoxiang/oriole-service)

- Prerequisites

  - python >= 3.5.2
  - mongodb
  - mysql
  - rabbitmq
  - redis-server
  
- Install oriole.

```
  pip install oriole-service
```

- Run unit tests.

```
  oriole test
```

![](https://github.com/zhouxiaoxiang/oriole-service/raw/master/docs/test.gif)

- Run a service. 

```
  oriole run <service>
```

![](https://github.com/zhouxiaoxiang/oriole-service/raw/master/docs/run.gif)

- Create documents. 

```
  oriole doc
```

![](https://github.com/zhouxiaoxiang/oriole-service/raw/master/docs/doc.gif)

- Run a client.

```
  oriole sh
```

![](https://github.com/zhouxiaoxiang/oriole-service/raw/master/docs/run.gif)
 
That's all.
